
import android.app.Activity;
import android.content.Context;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.view.Gravity;
import android.view.WindowManager;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;

import com.app.pokktsdk.PokktManager;
import android.graphics.Color;
import com.app.pokktsdk.util.Logger;

import org.json.JSONObject;

class PokktBannerAdapter {

    private static final int BANNER_WIDTH = 320;
    private static final int BANNER_HEIGHT = 50;

    private static RelativeLayout bannerContainer = null;

    interface IUIHelperFunction {
        void execute();
    }
    
    private static void runOnUiHelper(final IUIHelperFunction func, final Activity activity) {
        if (activity != null) {
            activity.runOnUiThread(new Runnable() {
                public void run() {
                    func.execute();
                }
            });
        } else {
            Logger.e("activity not found!");
        }
    }
    
    public static void loadBanner(String jsonString, final Activity activity) {
        try {
            Logger.d("loadBanner method called");
            final JSONObject jsonObject = new JSONObject(jsonString);
            final String screenName = jsonObject.optString("screenName");
            final int bannerTypes = Integer.parseInt(jsonObject.optString("bannerPosition"));
            
            // remove existing banner
            runOnUiHelper(new IUIHelperFunction() {
                @Override
                public void execute() {
                    if (bannerContainer != null) {
                        PokktManager.destroyBanner(bannerContainer);
                        bannerContainer = null;
                    }
                    
                    bannerContainer = new RelativeLayout(activity);
                    bannerContainer.setBackgroundColor(Color.TRANSPARENT);
                    activity.addContentView(bannerContainer, getLayoutParams(bannerTypes, activity));
                    PokktManager.loadBanner(activity, screenName, bannerContainer);
                }
            }, activity);
        }
        catch (Exception e) {
            Logger.printStackTrace(e);
        }
    }
    
    public static void loadBannerRect(String jsonString, final Activity activity) {
        try {
            Logger.d("loadBannerRect method called");
            
            final JSONObject jsonObject = new JSONObject(jsonString);
            final String screenName = jsonObject.optString("screenName");
            
            // setting this position when if developer is giving some value for x or y.
            final int width = Integer.parseInt(jsonObject.optString("width"));
            final int height = Integer.parseInt(jsonObject.optString("height"));
            
            // remove existing banner
            runOnUiHelper(new IUIHelperFunction() {
                @Override
                public void execute() {
                    if (bannerContainer != null) {
                        PokktManager.destroyBanner(bannerContainer);
                        bannerContainer = null;
                    }
                    
                    bannerContainer = new RelativeLayout(activity);
                    bannerContainer.setBackgroundColor(Color.TRANSPARENT);
                    bannerContainer.setX(Float.parseFloat(jsonObject.optString("x")));
                    bannerContainer.setY(Float.parseFloat(jsonObject.optString("y")));
                    activity.addContentView(bannerContainer, new RelativeLayout.LayoutParams(width, height));
                    PokktManager.loadBanner(activity, screenName, bannerContainer);
                }
            }, activity);
        }
        catch (Exception e) {
            Logger.printStackTrace(e);
        }
    }
    
    public static void removeBanner(final Activity activity) {
        if (bannerContainer != null) {
            runOnUiHelper(new IUIHelperFunction() {
                @Override
                public void execute() {
                    PokktManager.destroyBanner(bannerContainer);
                }
            }, activity);
        }
    }
    
    public static void bannerAutoRefresh(boolean shouldAutoRefresh) {
        if(bannerContainer != null)
            PokktManager.setBannerAutoRefresh(shouldAutoRefresh);
    }
    
    private static FrameLayout.LayoutParams getLayoutParams(int position, Activity activity) {
        FrameLayout.LayoutParams rlParams = new FrameLayout.LayoutParams(
                                                                         dpToPx(activity, BANNER_WIDTH), dpToPx(activity, BANNER_HEIGHT));
        
        switch (position) {
            case BannerPosition.TOP_LEFT:
                Logger.d("[POKKT-JAVA]: BannerPosition.TOP_LEFT");
                rlParams.gravity = Gravity.LEFT|Gravity.TOP;
                break;
            case BannerPosition.TOP_CENTER:
                Logger.d("[POKKT-JAVA]: BannerPosition.TOP_CENTER");
                rlParams.gravity = Gravity.CENTER|Gravity.TOP;
                break;
            case BannerPosition.TOP_RIGHT:
                Logger.d("[POKKT-JAVA]: BannerPosition.TOP_RIGHT");
                rlParams.gravity = Gravity.RIGHT|Gravity.TOP;
                break;
            case BannerPosition.MIDDLE_LEFT:
                Logger.d("[POKKT-JAVA]: BannerPosition.MIDDLE_LEFT");
                rlParams.gravity = Gravity.LEFT|Gravity.CENTER_VERTICAL;
                break;
            case BannerPosition.MIDDLE_CENTER:
                Logger.d("[POKKT-JAVA]: BannerPosition.MIDDLE_CENTER");
                rlParams.gravity = Gravity.CENTER_HORIZONTAL|Gravity.CENTER_VERTICAL;
                break;
            case BannerPosition.MIDDLE_RIGHT:
                Logger.d("[POKKT-JAVA]: BannerPosition.MIDDLE_RIGHT");
                rlParams.gravity = Gravity.RIGHT|Gravity.CENTER_VERTICAL;
                break;
            case BannerPosition.BOTTOM_LEFT:
                Logger.d("[POKKT-JAVA]: BannerPosition.BOTTOM_LEFT");
                rlParams.gravity = Gravity.LEFT|Gravity.BOTTOM;
                break;
            case BannerPosition.BOTTOM_CENTER:
                Logger.d("[POKKT-JAVA]: BannerPosition.BOTTOM_CENTER");
                rlParams.gravity = Gravity.CENTER|Gravity.BOTTOM;
                break;
            case BannerPosition.BOTTOM_RIGHT:
                Logger.d("[POKKT-JAVA]: BannerPosition.BOTTOM_RIGHT");
                rlParams.gravity = Gravity.RIGHT|Gravity.BOTTOM;
                break;
            default: //TOP_CENTER
                Logger.d("[POKKT-JAVA]: Did not find any matching request for banner position so setting to TOP_CENTER");
                rlParams.gravity = Gravity.LEFT|Gravity.TOP;
        }
        return rlParams;
    }
    
    private static int dpToPx(DisplayMetrics metrics, int dp) {
        float px = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, dp, metrics);
        if (px < 1.0f) {
            px = 1;
        }
        return (int) px;
    }
    
    private static int dpToPx(Context context, int dp) {
        DisplayMetrics metrics = new DisplayMetrics();
        WindowManager windowManager = (WindowManager) context.getSystemService(Context.WINDOW_SERVICE);
        windowManager.getDefaultDisplay().getMetrics(metrics);
        return dpToPx(metrics, dp);
    }
}
