//
//  AdScreen.cpp
//  PokktSample
//
//  Created by Pankaj Kumar on 22/04/15.
//
//

#include "AdScreen.h"
#include "IwGx.h"
#include "input.h"
#include "resources.h"
#include "UIComponents.h"
#include "PCPokktManager.h"
#include <sstream>
#include "Storage.h"
#include "PCEnums.h"

PCPokktConfig *AdScreen::pokktConfig = new PCPokktConfig();

AdScreen::AdScreen()
{
    POKKTLOG("[POKKT-MARMALADE][AdScreen]video download listener registered");
    
    // listen for pokkt events
    
    PCPokktManager::setAdEventListener(AD_AVAILABILITY_EVENT, PC_AD_EVENT_SELECTOR(AdScreen::handleAdAvailability), this);
    PCPokktManager::setAdEventListener(AD_CACHING_COMPLETED_EVENT, PC_AD_EVENT_SELECTOR(AdScreen::handleAdCachingCompleted), this);
    PCPokktManager::setAdEventListener(AD_CACHING_FAILED_EVENT, PC_AD_EVENT_SELECTOR(AdScreen::handleAdCachingFailed), this);
    PCPokktManager::setAdEventListener(AD_DISPLAYED_EVENT, PC_AD_EVENT_SELECTOR(AdScreen::handleAdDisplayed), this);
    PCPokktManager::setAdEventListener(AD_SKIPPED_EVENT, PC_AD_EVENT_SELECTOR(AdScreen::handleAdSkipped), this);
    PCPokktManager::setAdEventListener(AD_COMPLETED_EVENT, PC_AD_EVENT_SELECTOR(AdScreen::handleAdCompleted), this);
    PCPokktManager::setAdEventListener(AD_CLOSED_EVENT, PC_AD_EVENT_SELECTOR(AdScreen::handleAdClosed), this);
    PCPokktManager::setAdEventListener(AD_GRATIFIED_EVENT, PC_AD_EVENT_SELECTOR(AdScreen::handleAdGratified), this);
}

AdScreen::~AdScreen()
{
    PCPokktManager::removeAdEventListener(AD_AVAILABILITY_EVENT);
    PCPokktManager::removeAdEventListener(AD_CACHING_COMPLETED_EVENT);
    PCPokktManager::removeAdEventListener(AD_CACHING_FAILED_EVENT);
    PCPokktManager::removeAdEventListener(AD_DISPLAYED_EVENT);
    PCPokktManager::removeAdEventListener(AD_SKIPPED_EVENT);
    PCPokktManager::removeAdEventListener(AD_COMPLETED_EVENT);
    PCPokktManager::removeAdEventListener(AD_CLOSED_EVENT);
    PCPokktManager::removeAdEventListener(AD_GRATIFIED_EVENT);
}

void AdScreen::handleAdAvailability(PCAdConfig* adConfig, std::map<std::string, std::string> extraValues)
{
    POKKTLOG("[POKKT-MARMALADE][handleAdAvailability] Ad is available to watch");
}

void AdScreen::handleAdCachingCompleted(PCAdConfig* adConfig, std::map<std::string, std::string> extraValues)
{
    POKKTLOG("[POKKT-MARMALADE][handleAdCachingCompleted]");
    
    float adVc = 0;
    std::stringstream(extraValues[AD_VC]) >> adVc;

    if(adConfig->adFormat == VIDEO)
    {
        showButton(showVideoBtn);
        changeButtonLabelTest(showVideoLbl, "Show Video (Cached)");
    }
    else if(adConfig->adFormat == INTERSTITIAL)
    {
        showButton(showInterstitialBtn);
        changeButtonLabelTest(showInterstitialLbl, "Show Interstitial (Cached)");
    }
}

void AdScreen::handleAdCachingFailed(PCAdConfig* adConfig, std::map<std::string, std::string> extraValues)
{
    POKKTLOG("[POKKT-MARMALADE][handleAdCachingFailed] Ad Caching Failed");
    resetAllButton(adConfig);
}

void AdScreen::handleAdDisplayed(PCAdConfig* adConfig, std::map<std::string, std::string> extraValues)
{
    POKKTLOG("[POKKT-MARMALADE][handleAdDisplayed]");
    //msgLbl->SetText(message.c_str());
}

void AdScreen::handleAdSkipped(PCAdConfig* adConfig, std::map<std::string, std::string> extraValues)
{
    POKKTLOG("[POKKT-MARMALADE][handleAdSkipped] Ad has been skipped");
}

void AdScreen::handleAdCompleted(PCAdConfig* adConfig, std::map<std::string, std::string> extraValues)
{
    POKKTLOG("[POKKT-MARMALADE][handleAdCompleted] Ad has been watched fully");
}

void AdScreen::handleAdClosed(PCAdConfig* adConfig, std::map<std::string, std::string> extraValues)
{
    POKKTLOG("[POKKT-MARMALADE][handleAdClosed] Ad has been closed");
    resetAllButton(adConfig);
}

void AdScreen::handleAdGratified(PCAdConfig* adConfig, std::map<std::string, std::string> extraValues)
{
    POKKTLOG("[POKKT-MARMALADE][handleAdGratified] Rewarded successfully after watching Ad %s", extraValues[REWARD].c_str());
    char buf[100] = "";
    sprintf(buf, "%s", extraValues[REWARD].c_str());
    std::string earnedText("Earned points: ");
    std::string earnedPoint(extraValues[REWARD].c_str());
    pointsEarnedLbl->SetText((earnedText + earnedPoint).c_str());
}

void AdScreen::hideButton(CSprite *sprite)
{
    sprite->m_IsVisible = false;
    sprite->m_IsVisible = false;
}

void AdScreen::showButton(CSprite *sprite)
{
    sprite->m_IsVisible = true;
    sprite->m_IsVisible = true;
}

void AdScreen::changeButtonLabelTest(CLabel *label, std::string text)
{
    label->SetText(text);
}

void AdScreen::resetAllButton(PCAdConfig* adConfig)
{
    if(adConfig->adFormat == VIDEO)
    {
        cacheVideoBtn->m_IsVisible = true;
        showVideoBtn->m_IsVisible = true;
        cacheVideoLbl->SetText("Start Video Caching");
        showVideoLbl->SetText("Show Incent Video(without caching)");
    }
    else if(adConfig->adFormat == INTERSTITIAL)
    {
        cacheInterstitialBtn->m_IsVisible = true;
        showInterstitialBtn->m_IsVisible = true;
        cacheInterstitialLbl->SetText("Start Interstitial Caching");
        showInterstitialLbl->SetText("Show Non-Incent Interstitial(without caching)");
    }
}

void AdScreen::Update(float deltaTime, float alphaMul)
{
    if(!m_IsActive)
        return;
    
    Scene:Scene::Update(deltaTime, alphaMul);
    
    //Detect screen tap
    if(m_IsInputActive && m_Manager->GetCurrent() == this && !g_pInput->m_Touched && g_pInput->m_PrevTouched)
    {
        g_pInput->Reset();
        
        if(cacheVideoBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            hideButton(cacheVideoBtn);
            hideButton(showVideoBtn);
            
            videoAdConfig = new PCAdConfig();
            videoAdConfig->screenName = screenName;
            videoAdConfig->isRewarded = isReward;
            videoAdConfig->adFormat = VIDEO;
            PCPokktManager::cacheAd(videoAdConfig);
        }
        else if(showVideoBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            if(videoAdConfig != NULL)
            {
                PCPokktManager::showAd(videoAdConfig);
            }
            else
            {
                videoAdConfig = new PCAdConfig();
                videoAdConfig->screenName = screenName;
                videoAdConfig->isRewarded = isReward;
                videoAdConfig->adFormat = VIDEO;
                PCPokktManager::showAd(videoAdConfig);
            }
        }
        else if(cacheInterstitialBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            hideButton(cacheInterstitialBtn);
            hideButton(showInterstitialBtn);
            
            interstitialAdConfig = new PCAdConfig();
            interstitialAdConfig->screenName = screenName;
            interstitialAdConfig->isRewarded = isReward;
            interstitialAdConfig->adFormat = INTERSTITIAL;
            PCPokktManager::cacheAd(interstitialAdConfig);
        }
        else if(showInterstitialBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            if(interstitialAdConfig != NULL)
            {
                interstitialAdConfig->isRewarded = false;
                PCPokktManager::showAd(interstitialAdConfig);
            }
            else
            {
                interstitialAdConfig = new PCAdConfig();
                interstitialAdConfig->screenName = screenName;
                interstitialAdConfig->isRewarded = false;
                interstitialAdConfig->adFormat = INTERSTITIAL;
                PCPokktManager::showAd(interstitialAdConfig);
            }
        }
        else if(exportLogBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            PCPokktManager::exportLog();
        }
    }
}

void AdScreen::Render()
{
    Scene::Render();
}

void AdScreen::Init()
{
    Scene::Init();
    
    // Create UI
    CSprite* background = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() / 2, g_pResources->getScreenBG(), 0.5f, 0.5f);
    // Fit background to screen size
    background->m_ScaleX = (float)IwGxGetScreenWidth() / background->GetImage()->GetWidth();
    background->m_ScaleY = (float)IwGxGetScreenHeight() / background->GetImage()->GetHeight();
    AddChild(background);
    
    CSprite* logo = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() * 0.15f, g_pResources->getLogo(), 0.5f, 0.5f);
    AddChild(logo);
    
    screenNameLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, (float)IwGxGetScreenHeight() * 0.26f, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Screen Name: ");
    //AddChild(screenNameLbl);
    
    //
    float y_pos = (float)IwGxGetScreenHeight() * 0.45f;
    pointsEarnedLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Points earned: 0");
    AddChild(pointsEarnedLbl);
    
//Cache Video Button
    y_pos = (float)IwGxGetScreenHeight() * 0.56f;
    cacheVideoBtn = UIComponents::getSprite(IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(cacheVideoBtn);
    
    y_pos = (float)IwGxGetScreenHeight() * 0.575f;
    cacheVideoLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Start Video Caching");
    AddChild(cacheVideoLbl);
    
//Show Video Button
    y_pos = (float)IwGxGetScreenHeight() * 0.64f;
    showVideoBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getPurpleButton(), 0.5f, 0.5f);
    AddChild(showVideoBtn);
    
    y_pos = (float)IwGxGetScreenHeight() * 0.655f;
    showVideoLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Show Incent Video(without caching)");
    AddChild(showVideoLbl);
    
//Cache Interstitial Button
    y_pos = (float)IwGxGetScreenHeight() * 0.72f;
    cacheInterstitialBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(cacheInterstitialBtn);
    
    y_pos = (float)IwGxGetScreenHeight() * 0.735f;
    cacheInterstitialLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Start Interstitial Caching");
    AddChild(cacheInterstitialLbl);
    
//Show Interstitial Button
    y_pos = (float)IwGxGetScreenHeight() * 0.80f;
    showInterstitialBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getPurpleButton(), 0.5f, 0.5f);
    AddChild(showInterstitialBtn);
    
    y_pos = (float)IwGxGetScreenHeight() * 0.815f;
    showInterstitialLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Show Incent Interstitial(without caching)");
    AddChild(showInterstitialLbl);
    
//Export log button
        y_pos = (float)IwGxGetScreenHeight() * 0.88f;
        exportLogBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getPurpleButton(), 0.5f, 0.5f);
        AddChild(exportLogBtn);
    
        y_pos = (float)IwGxGetScreenHeight() * 0.895f;
        CLabel* exportLogBtnLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Export SDK Log");
        AddChild(exportLogBtnLbl);

}

void AdScreen::updateAdScreen(std::string screen, bool isRewarded)
{
    screenName = screen;
    isReward = isRewarded;
    //screenNameLbl->SetText(screenName);
}
