//
//  SelectorScreen.cpp
//  PokktSample
//
//  Created by Pankaj Kumar on 22/04/15.
//
//

#include "SelectorScreen.h"
#include "IwGx.h"
#include "input.h"
#include "resources.h"
#include "mainMenu.h"
#include "UIComponents.h"
#include "PCPokktManager.h"
#include "Storage.h"
#include "PCEnums.h"
#include "AdScreen.h"
#include "OfferwallScreen.h"
#include "IAPDetails.h"

PCPokktConfig *SelectorScreen::pokktConfig = new PCPokktConfig();

SelectorScreen::SelectorScreen()
{
    PCPokktManager::setPokktInitializedListener(PC_POKKT_INITIALIZED_EVENT_SELECTOR(SelectorScreen::handlePokktInitialized), this);
    PCPokktManager::setBannerEventListener(BANNER_LOADED_EVENT, PC_BANNER_EVENT_SELECTOR(SelectorScreen::handleBannerLoaded), this);
    PCPokktManager::setBannerEventListener(BANNER_LOAD_FAILED_EVENT, PC_BANNER_EVENT_SELECTOR(SelectorScreen::handleBannerLoadFailed), this);
}

SelectorScreen::~SelectorScreen() { }

void SelectorScreen::Update(float deltaTime, float alphaMul)
{
    if(!m_IsActive)
        return;
    
    Scene:Scene::Update(deltaTime, alphaMul);
    
    //Detect screen tap
    if(m_IsInputActive && m_Manager->GetCurrent() == this && !g_pInput->m_Touched && g_pInput->m_PrevTouched)
    {
        g_pInput->Reset();
        if(initializeBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            initializeBtn->m_IsVisible = false;
            initPokkt();
        }
        else if(testRewardBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            AdScreen* adScreen = (AdScreen*)g_pSceneManager->Find("adscreen");
            adScreen->updateAdScreen("abcd", true);
            g_pSceneManager->SwitchTo(adScreen);
        }
        else if(testNonRewardBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            AdScreen* adScreen = (AdScreen*)g_pSceneManager->Find("adscreen");
            adScreen->updateAdScreen("abcd", false);
            g_pSceneManager->SwitchTo(adScreen);
        }
        else if(offerwallBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            OfferwallScreen* offerwallScreen = (OfferwallScreen*)g_pSceneManager->Find("offerwallscreen");
            offerwallScreen->pokktConfig = pokktConfig;
            g_pSceneManager->SwitchTo(offerwallScreen);
        }
        else if(showBannerBtn->HitTest(g_pInput->m_X, g_pInput->m_Y))
        {
            PCPokktManager::loadBanner("abcd", TOP_CENTER);
            //PCPokktManager::loadBannerWithRect("abcd", 320, 100, 100, 100);
        }
    }
}

void SelectorScreen::handlePokktInitialized(std::string message, bool isReady)
{
    POKKTLOG("[POKKT-CPP][handlePokktInitialized]: message %s", message.c_str());
    POKKTLOG("[POKKT-CPP][handlePokktInitialized] isReady %d", isReady);
    isPokktReady = isReady;
    if(isReady)
    {
        initializeBtn->m_IsVisible = false;
        testRewardBtn->m_IsVisible = true;
        testNonRewardBtn->m_IsVisible = true;
        offerwallBtn->m_IsVisible = true;
        showBannerBtn->m_IsVisible = true;
        
//        IAPDetails *iapDetails = new IAPDetails();
//        iapDetails->productId = "123";
//        iapDetails->price = 100;
//        iapDetails->currencyCode = "IN";
//        iapDetails->title = "iapDetails";
//        iapDetails->description = "description";
//        iapDetails->purchaseData = "1-1-2016";
//        iapDetails->purchaseSignature = "pankaj";
//        iapDetails->purchaseStore = POKKT_IAP_STORE_TYPE_GOOGLE;
//        
//        POKKTLOG("[Pokkt-Marmalade] Sending trackAPI");
//        PCPokktManager::trackIAP(iapDetails);
//        PCPokktManager::notifyAppInstall();
    }
    else
    {
        initializeBtn->m_IsVisible = true;
    }
}

void SelectorScreen::handleBannerLoaded(std::string screenName, std::string message)
{
    POKKTLOG("Banner loaded for screen name: %s", screenName.c_str());
}

void SelectorScreen::handleBannerLoadFailed(std::string screenName, std::string errorMessage)
{
    POKKTLOG("Banner load failed for screen name: %s, and error message is: %s", screenName.c_str(), errorMessage.c_str());
}

void SelectorScreen::initPokkt()
{
    PCPokktManager::setDebug(true);
    
    //android
    pokktConfig->securityKey = "iJ02lJss0M";
    pokktConfig->applicationId = "a2717a45b835b5e9f50284a38d62a74e";
        
    // pokkt init for video ads
    pokktConfig->thirdPartyUserId = "123456";
    POKKTLOG("[POKKT-CPP][SelectorScreen] Pokkt SDK Version: %s", PCPokktManager::getSDKVersion().c_str());
    pokktConfig->mobileNo = "999999999";
    pokktConfig->age = "32";
    pokktConfig->birthday = "20/08/1983";
    pokktConfig->education = "MCA";
    pokktConfig->emailAddress = "abc@gmail.com";
    pokktConfig->employment = "Engineer";
    pokktConfig->facebookId = "abcdefg";
    pokktConfig->location = "Bangalore";
    pokktConfig->maritalStatus = "Married";
    pokktConfig->maturityRating = "for all";
    pokktConfig->name = "Pankaj";
    pokktConfig->nationality = "Indian";
    pokktConfig->sex = "Male";
    pokktConfig->twitterHandle = "pankajabc";
    
    //pokktConfig->selectedAnalyticsType = POKKT_ANALYTICS_TYPE_GOOGLE_ANALYTICS;
    //pokktConfig->googleAnalyticsID = "12345";
    
    PCPokktManager::initPokkt(pokktConfig);
}

void SelectorScreen::Render()
{
    Scene::Render();
}

void SelectorScreen::Init()
{
    Scene::Init();
    
    std::string screenName = "abcd";
    
    // Create UI
    CSprite* background = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() / 2, g_pResources->getScreenBG(), 0.5f, 0.5f);
    // Fit background to screen size
    background->m_ScaleX = (float)IwGxGetScreenWidth() / background->GetImage()->GetWidth();
    background->m_ScaleY = (float)IwGxGetScreenHeight() / background->GetImage()->GetHeight();
    AddChild(background);
    
    CSprite* logo = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2, (float)IwGxGetScreenHeight() * 0.22f, g_pResources->getLogo(), 0.5f, 0.5f);
    AddChild(logo);
    
    CLabel* screenNameLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, (float)IwGxGetScreenHeight() * 0.36f, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Screen Name: " + screenName);
    AddChild(screenNameLbl);
    
    //Button

    //Initialise button
    float y_pos = (float)IwGxGetScreenHeight() * 0.46f;
    initializeBtn = UIComponents::getSprite(IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getPurpleButton(), 0.5f, 0.5f);
    AddChild(initializeBtn);
    
    y_pos = (float)IwGxGetScreenHeight() * 0.475f;
    CLabel* initializeBtnLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Initialize Pokkt");
    AddChild(initializeBtnLbl);
    
    //Demo Screen1 button
    y_pos = (float)IwGxGetScreenHeight() * 0.54f;
    testRewardBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(testRewardBtn);
    testRewardBtn->m_IsVisible = false;
    
    y_pos = (float)IwGxGetScreenHeight() * 0.555f;
    CLabel* demoScreen1BtnLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Test Reward Ad");
    AddChild(demoScreen1BtnLbl);
    
    //Demo Screen2 button
    y_pos = (float)IwGxGetScreenHeight() * 0.62f;
    testNonRewardBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(testNonRewardBtn);
    testNonRewardBtn->m_IsVisible = false;
    
    y_pos = (float)IwGxGetScreenHeight() * 0.635f;
    CLabel* demoScreen2BtnLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Test Non Reward Ad");
    AddChild(demoScreen2BtnLbl);

    //Offer button
    y_pos = (float)IwGxGetScreenHeight() * 0.70f;
    offerwallBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getBlueButton(), 0.5f, 0.5f);
    AddChild(offerwallBtn);
    offerwallBtn->m_IsVisible = false;
    
    y_pos = (float)IwGxGetScreenHeight() * 0.715f;
    CLabel* offerwallBtnLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Test Offerwall");
    AddChild(offerwallBtnLbl);

    //Banner button
    y_pos = (float)IwGxGetScreenHeight() * 0.78f;
    showBannerBtn = UIComponents::getSprite((float)IwGxGetScreenWidth() / 2.0f, y_pos, g_pResources->getPurpleButton(), 0.5f, 0.5f);
    AddChild(showBannerBtn);
    
    y_pos = (float)IwGxGetScreenHeight() * 0.795f;
    CLabel* showBannerBtnLbl = UIComponents::getLabel((float)IwGxGetScreenWidth() / 2.0f, y_pos, (float)IwGxGetScreenWidth(), 30, 0.5f, 0.5f, IW_2D_FONT_ALIGN_CENTRE, IW_2D_FONT_ALIGN_TOP, CColor(0xff, 0xff, 0x30, 0xff), "Test Banner");
    AddChild(showBannerBtnLbl);
    showBannerBtn->m_IsVisible = false;    
}
