
#include "Iw2D.h"
#include "input.h"
#include "scene.h"
#include "resources.h"
#include "mainMenu.h"
#include "SelectorScreen.h"
#include "AdScreen.h"
#include "OfferwallScreen.h"
#include "VideoNextScreen.h"
#include "PCPokktManager.h"
#include <iostream>
#include <string>

// FRAME_TIME is the amount of time that a single frame should last in seconds
#define FRAME_TIME  (30.0f / 1000.0f)

bool g_DeviceHasKeyboard = false;
SelectorScreen* selectorScreen;
OfferwallScreen* offerwallScreen;
AdScreen* adScreen;

void terminate()
{
    // Clean-up
    delete g_pInput;
    delete g_pSceneManager;
    delete g_pResources;
    Iw2DTerminate();
}

static int32 handler(void* sys, void*)
{
    s3eKeyboardEvent* event = (s3eKeyboardEvent*)sys;
    s3eDebugTracePrintf("button clicked");
    return 0;
}

int changeScreen()
{
    std::string sceneName = g_pSceneManager->GetCurrent()->getSceneName();
    
    if(sceneName.compare(selectorScreen->getSceneName()) == 0)
    {
        return 0;
    }
    else if(sceneName.compare(offerwallScreen->getSceneName()) == 0)
    {
        g_pSceneManager->SwitchTo(selectorScreen);
        return 1;
    }
    else if(sceneName.compare(adScreen->getSceneName()) == 0)
    {
         g_pSceneManager->SwitchTo(selectorScreen);
        return 1;
    }
    else
    {
        return 1;
    }
}

int32 PausedNotificationRecieved(void *systemData, void *userData)
{
    s3eDebugTracePrintf("--------------App Paused-------------------");
    return 0;
}

int32 UnPausedNotificationRecieved(void *systemData, void *userData)
{
    s3eDebugTracePrintf("--------------App Resumed-----------------");
    return 0;
}

int main()
{
    // Initialise the 2D graphics system
    Iw2DInit();

    // Create resources
    g_pResources = new Resources();

    // Set up input systems
    g_pInput = new Input();

    // Create scene manager
    g_pSceneManager = new SceneManager();

    selectorScreen = new SelectorScreen();
    selectorScreen->SetName("selectorscreen");
    selectorScreen->Init();
    g_pSceneManager->Add(selectorScreen);
    
    offerwallScreen = new OfferwallScreen();
    offerwallScreen->SetName("offerwallscreen");
    offerwallScreen->Init();
    g_pSceneManager->Add(offerwallScreen);

    adScreen = new AdScreen();
    adScreen->SetName("adscreen");
    adScreen->Init();
    g_pSceneManager->Add(adScreen);

    // Switch to main menu scene
    g_pSceneManager->SwitchTo(selectorScreen);

    // Loop forever, until the user or the OS performs some action to quit the app
    
    //s3eDeviceRegister(S3E_DEVICE_NOTIFY_PAUSE, PausedNotificationRecieved, 0);
    //s3eDeviceRegister(S3E_DEVICE_NOTIFY_UNPAUSE, UnPausedNotificationRecieved, 0);
    
    while (true)
    {
        // Yield to the OS
        s3eDeviceYield(0);
        
        s3eKeyboardUpdate();
        //s3ePointerUpdate();
        if ((s3eKeyboardGetState(s3eKeyEsc) & S3E_KEY_STATE_RELEASED) == S3E_KEY_STATE_RELEASED ||
            (s3eKeyboardGetState(s3eKeyBack) & S3E_KEY_STATE_RELEASED) == S3E_KEY_STATE_RELEASED ||
            (s3eKeyboardGetState(s3eKeyAbsBSK) & S3E_KEY_STATE_RELEASED) == S3E_KEY_STATE_RELEASED
            || (s3eDeviceCheckQuitRequest()))
        {
            //change screen
            if(changeScreen() == 0)
            {
                PCPokktManager::endSession();
                //terminatePokktNativeManager is mendatory to call.
                PCPokktManager::unhookCallbackReceiver();
                break;
            }
        }
        // Update input system
        g_pInput->Update();
        
        //if (g_Input.isKeyDown(s3eKeyAbsBSK))	// Back key is used to exit on some platforms
        //    break;

        // Update scene manager
        g_pSceneManager->Update(FRAME_TIME);

        // Clear the drawing surface
        Iw2DSurfaceClear(0xff000000);

        // Render scene manager
        g_pSceneManager->Render();

        // Show the drawing surface
        Iw2DSurfaceShow();

        
    }

    terminate();
    
    return 0;
}
